pub enum Consent {
Granted,
NotGranted,
}Expand description
Customer-message consent state used before grooming reminder drafts proceed.
Variants
Granted
Staff can see the granted grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.
NotGranted
Staff can see the not granted grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.