Enum Kind
Source pub enum Kind {
AppointmentConfirmation,
PrepInstructions,
MorningOf,
RebookingDue,
LapsedCadenceWinback,
}
Reminder purpose for grooming confirmations, prep instructions, and cadence follow-up drafts.
Staff can see the appointment confirmation grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.
Staff can see the prep instructions grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.
Staff can see the morning of grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.
Staff can see the rebooking due grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.
Staff can see the lapsed cadence winback grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Deserialize this value from the given Serde deserializer.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Serialize this value into the given Serde serializer.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.