pub enum Rule {
OneWeekBefore,
FortyEightHoursBefore,
MorningOf,
}Expand description
Rebooking rule that tells staff whether history only, deposit review, or manager review applies.
Variants
OneWeekBefore
Staff can see the one week before grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.
FortyEightHoursBefore
Staff can see the forty eight hours before grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.
MorningOf
Staff can see the morning of grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.