pub enum SendBoundary {
DraftRequiresApproval,
ReadyForApprovedSend,
SuppressedUntilConsent,
}Expand description
Customer-message send status for grooming reminder plans.
Variants
DraftRequiresApproval
Staff can see the draft requires approval grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.
ReadyForApprovedSend
Staff can see the ready for approved send grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.
SuppressedUntilConsent
Staff can see the suppressed until consent grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.