pub enum Rule {
OneWeekBefore,
FortyEightHoursBefore,
MorningOf,
}Expand description
Decision vocabulary for rule in grooming workflows.
Variants
OneWeekBefore
One week before grooming operational signal for schedule, estimate, history, or review handling.
FortyEightHoursBefore
Forty eight hours before grooming operational signal for schedule, estimate, history, or review handling.
MorningOf
Morning of grooming operational signal for schedule, estimate, history, or review handling.